from django.core.management.base import NoArgsCommand
import sys


class Command(NoArgsCommand):

    help = "Runs a Python interactive interpreter using the IPython notebook."
    requires_model_validation = False

    def ipython_notebook(self):
        # analogous to the calls in the django.core shell command
        from IPython.frontend.html.notebook.notebookapp import NotebookApp
        app = NotebookApp.instance() 
        # except for this bit, we we pass sys.argv to the ipython
        # interpreter, so that it gets the location of manage.py,
        # inserting it into the PYTHONPATH and making it the default
        # notebook directory.
        app.initialize(argv=sys.argv) 
        app.start()

    def handle_noargs(self, **options):
        # workaround taken from django.core.management.commands.shell
        # XXX: (Temporary) workaround for ticket #1796: force early loading of all
        # models from installed apps.
        from django.db.models.loading import get_models
        get_models()

        self.ipython_notebook()






from setuptools import setup, find_packages

setup(
    name='django-shell-ipynb',
    version='0.1.0',
    description='A Django management command "shell_ipynb" that uses the ipython notebook instead of ipython.',
    long_description=open('README.rst').read(),
    # Get more strings from http://www.python.org/pypi?:action=list_classifiers
    author='Charl P. Botha',
    author_email='cpbotha@vxlabs.com',
    url='https://github.com/cpbotha/django-shell-ipynb',
    license='BSD',
    # gets nested packages also, including
    # django_shell_ipynb.management.commands
    packages=find_packages(),
    install_requires = ['ipython', 'tornado', 'pyzmq'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
